import axios from "axios";

export default {
  fetchCustomerData({ commit, getters }, data = {}) {
    let query;
    if (data.filterColumn == "all") {
      query = "q=" + data.searchInput;
    } else if (data.filterColumn) {
      query = data.filterColumn + "_like=" + data.searchInput;
    }

    let pageLimit = `&_page=${getters.getOptions.page}&_limit=${getters.getOptions.itemsPerPage}`;

    if (data.searchInput) {
      pageLimit = "";
    }

    let sort = getters.getOptions.sortDesc[0] ? "desc" : "asc";

    let sortBy = `&_sort=${getters.getOptions.sortBy}&_order=${sort}`;

    commit("setLoading", true);
    axios
      .get(`http://localhost:3000/customers?${query}${pageLimit}${sortBy}`)
      .then((response) => {
        commit("setTotalCustomers", response.headers["x-total-count"]);
        commit("setCustomerList", response.data);
        commit("setLoading", false);
      })
      .catch((e) => {
        console.log(e);
      });
  },

  setOptions({ commit, dispatch }, data) {
    commit("setOptions", data);
    dispatch("fetchCustomerData");
  },

  closeDialog({ commit }) {
    commit("setDialog", false);
  },

  deleteCustomer({ dispatch, commit }, idList) {
    confirm("Are you sure you want to delete this item?") &&
      idList.forEach((id) => {
        commit("setLoading", true);
        axios
          .delete(`http://localhost:3000/customers/${id}`)
          .then(() => {
            dispatch("fetchCustomerData");
            commit("setLoading", false);
          })
          .catch((e) => {
            console.log(e);
          });
      });
  },
  deleteMultiCustomer({ dispatch }, items) {
    const itemList = [];
    items.forEach((item) => {
      itemList.push(item.id);
    });
    dispatch("deleteCustomer", itemList);
  },

  saveCustomer({ getters, dispatch, commit }) {
    const postConfig = {
      method: "post",
      url: `http://localhost:3000/customers/`,
      data: getters.editedItem,
    };

    const putConfig = {
      method: "put",
      url: `http://localhost:3000/customers/${getters.editedItem.id}`,
      data: getters.editedItem,
    };
    commit("setLoading", true);
    axios(!getters.editedItem.id ? postConfig : putConfig).then(() => {
      dispatch("fetchCustomerData");
      commit("setLoading", false);
    });
    dispatch("closeDialog");
  },

  editCustomer({ commit, getters }, item) {
    commit("setEditedIndex", getters.customerList.indexOf(item));
    commit("setEditedItem", Object.assign({}, item));
    commit("setDialog", true);
  },
};
